<?php

/**
 * Theme functions and definitions
 *
 * @package Purosa
 */

if ( !defined( 'ABSPATH' ) ) {
    exit;
    // Direct access not allowed.
}


if ( !function_exists( 'purosa_fs' ) ) {
    // Create a helper function for easy SDK access.
    function purosa_fs()
    {
        global  $purosa_fs ;
        
        if ( !isset( $purosa_fs ) ) {
            // Include Freemius SDK.
            require_once dirname( __FILE__ ) . '/freemius/start.php';
            $purosa_fs = fs_dynamic_init( array(
                'id'              => '5191',
                'slug'            => 'purosa',
                'type'            => 'theme',
                'public_key'      => 'pk_4080480afd3e5c08ed89e475b4ce7',
                'is_premium'      => false,
                'premium_suffix'  => 'Premium',
                'has_addons'      => false,
                'has_paid_plans'  => true,
                'has_affiliation' => 'selected',
                'menu'            => array(
                'slug'    => 'getting-started',
                'support' => false,
                'parent'  => array(
                'slug' => 'themes.php',
            ),
            ),
                'is_live'         => true,
            ) );
        }
        
        return $purosa_fs;
    }
    
    // Init Freemius.
    purosa_fs();
    // Signal that SDK was initiated.
    do_action( 'purosa_fs_loaded' );
}

// Set the content width based on the theme's design and stylesheet.

if ( !isset( $content_width ) ) {
    $content_width = 1170;
    /* pixels */
}

// Constants
define( 'PUROSA_THEME_DIR', get_template_directory() );
define( 'PUROSA_THEME_URI', get_template_directory_uri() );
// Includes
require PUROSA_THEME_DIR . '/includes/theme-setup.php';
require PUROSA_THEME_DIR . '/includes/theme-functions.php';
require PUROSA_THEME_DIR . '/includes/template-parts.php';
require PUROSA_THEME_DIR . '/includes/admin/theme-admin.php';
require PUROSA_THEME_DIR . '/includes/class-purosa-nav-walker.php';
require PUROSA_THEME_DIR . '/includes/class-purosa-comments-walker.php';
require PUROSA_THEME_DIR . '/includes/customizer.php';
// Theme styles
function purosa_theme_styles()
{
    wp_enqueue_style( 'purosa-font-icons', PUROSA_THEME_URI . '/assets/css/font-icons.css' );
    wp_enqueue_style( 'purosa-styles', get_stylesheet_uri(), array( 'purosa-font-icons' ) );
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
    // Fonts
    if ( !class_exists( 'Kirki' ) ) {
        wp_enqueue_style( 'purosa-google-fonts', '//fonts.googleapis.com/css?family=Roboto:400,400i,500,600,700' );
    }
}

add_action( 'wp_enqueue_scripts', 'purosa_theme_styles' );
/**
* Gutenberg backend styles.
*/
function purosa_gutenberg_assets()
{
    wp_enqueue_style( 'purosa-gutenberg-editor-styles', get_theme_file_uri( '/assets/css/gutenberg-editor-style.css' ), false );
    if ( !class_exists( 'Kirki' ) ) {
        wp_enqueue_style( 'purosa-gutenberg-editor-google-fonts', '//fonts.googleapis.com/css?family=Roboto:400,400i,500,600,700' );
    }
}

add_action( 'enqueue_block_editor_assets', 'purosa_gutenberg_assets' );
/**
 * Theme scripts
 */
function purosa_theme_js()
{
    wp_enqueue_script(
        'bootstrap',
        PUROSA_THEME_URI . '/assets/js/bootstrap.min.js',
        array( 'jquery' ),
        '4.0.0',
        true
    );
    wp_enqueue_script(
        'modernizr',
        PUROSA_THEME_URI . '/assets/js/modernizr.js',
        array( 'jquery' ),
        '3.4.0',
        true
    );
    wp_enqueue_script( 'masonry' );
    wp_enqueue_script(
        'sticky-kit',
        PUROSA_THEME_URI . '/assets/js/sticky-kit.min.js',
        array( 'jquery' ),
        '1.1.2',
        true
    );
    wp_enqueue_script(
        'owl-carousel',
        PUROSA_THEME_URI . '/assets/js/owl.carousel.min.js',
        array( 'jquery' ),
        '2.2.1',
        true
    );
    wp_register_script(
        'purosa-scripts',
        PUROSA_THEME_URI . '/assets/js/scripts.js',
        array( 'jquery' ),
        '1.0.0',
        true
    );
    wp_enqueue_script( 'purosa-scripts' );
    $purosa_php_data = array(
        'home_url' => esc_url( home_url( '/' ) ),
    );
    wp_localize_script( 'purosa-scripts', 'purosa_php_data', $purosa_php_data );
}

add_action( 'wp_enqueue_scripts', 'purosa_theme_js' );
/**
 * Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function purosa_skip_link_focus_fix()
{
    // The following is minified via `terser --compress --mangle -- assets/js/skip-link-focus-fix.js`.
    ?>
	<script>
	/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
	</script>
	<?php 
}

add_action( 'wp_print_footer_scripts', 'purosa_skip_link_focus_fix' );
/**
 * Theme admin scripts and styles.
 */
function purosa_admin_scripts()
{
    $screen = get_current_screen();
    wp_enqueue_style( 'purosa-admin-styles', PUROSA_THEME_URI . '/assets/admin/css/admin-styles.css' );
    
    if ( $screen->id === 'appearance_page_one-click-demo-import' ) {
        wp_register_script(
            'purosa-admin-scripts',
            PUROSA_THEME_URI . '/assets/admin/js/purosa-admin-scripts.js',
            array( 'jquery-core' ),
            false,
            true
        );
        wp_enqueue_script( 'purosa-admin-scripts' );
    }

}

add_action( 'admin_enqueue_scripts', 'purosa_admin_scripts' );
/**WP Customizer styles and scripts
 */
function purosa_customizer_enqueue_scripts()
{
    wp_enqueue_style( 'purosa-customizer-styles', PUROSA_THEME_URI . '/assets/css/customizer/customizer.css' );
}

add_action( 'customize_controls_enqueue_scripts', 'purosa_customizer_enqueue_scripts' );