<?php
/**
 * Theme admin functions.
 *
 * @package Purosa
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

/**
* Add admin menu
*
* @since 1.0.0
*/
function purosa_theme_admin_menu() {
	add_theme_page(
		__( 'Getting Started', 'purosa' ),
		__( 'Purosa', 'purosa' ),
		'manage_options',
		'getting-started',
		'purosa_admin_page_content',
		30
	);
}
add_action( 'admin_menu', 'purosa_theme_admin_menu' );


/**
* Add admin page content
*
* @since 1.0.0
*/
function purosa_admin_page_content() {
	$purosa_urls = array(
		'docs' 									=> 'https://docs.deothemes.com/purosa/',	
		'homepage-templates'		=> 'https://docs.deothemes.com/purosa/knowledgebase/3-homepage-templates/',
		'custom-widgets'				=> 'https://docs.deothemes.com/purosa/knowledgebase/widgets/',		
		'elementor-widgets'			=> 'https://docs.deothemes.com/purosa/knowledgebase/elementor-custom-widgets/',
		'gdpr'									=> 'https://docs.deothemes.com/purosa/knowledgebase/gdpr/',
		'socials'								=> 'https://docs.deothemes.com/purosa/knowledgebase/socials/',		
		'demo-import'						=> 'https://docs.deothemes.com/purosa/knowledgebase/theme-installation/',
		'woocommerce' 					=> 'https://docs.deothemes.com/purosa/knowledgebase/woocommerce/',
	);

	$purosa_info = array(
		'homepage-templates' => array(
			'title'			=> __( '3 Homepage Templates', 'purosa' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $purosa_urls['homepage-templates'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $purosa_urls['homepage-templates'],
					'link_text'    => __( 'Learn More &#187;', 'purosa' ),
					'target_blank' => true
				),
			),
		),
		'custom-widgets' => array(
			'title'			=> __( 'Custom Widgets', 'purosa' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $purosa_urls['custom-widgets'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $purosa_urls['custom-widgets'],
					'link_text'    => __( 'Learn More &#187;', 'purosa' ),
					'target_blank' => true
				),
			),
		),
		'elementor-widgets' => array(
			'title'			=> __( 'Premium Elementor Widgets', 'purosa' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $purosa_urls['elementor-widgets'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $purosa_urls['elementor-widgets'],
					'link_text'    => __( 'Learn More &#187;', 'purosa' ),
					'target_blank' => true
				),
			),
		),
		'gdpr' => array(
			'title'			=> __( 'GDPR', 'purosa' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $purosa_urls['gdpr'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $purosa_urls['gdpr'],
					'link_text'    => __( 'Learn More &#187;', 'purosa' ),
					'target_blank' => true
				),
			),
		),
		'socials' => array(
			'title'			=> __( 'Social Media', 'purosa' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $purosa_urls['socials'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $purosa_urls['socials'],
					'link_text'    => __( 'Learn More &#187;', 'purosa' ),
					'target_blank' => true
				),
			),
		),
		'demo-import' => array(
			'title'			=> __( 'One Click Demo Import', 'purosa' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $purosa_urls['demo-import'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $purosa_urls['demo-import'],
					'link_text'    => __( 'Learn More &#187;', 'purosa' ),
					'target_blank' => true
				),
			),
		),
		'woocommerce' => array(
			'title'			=> __( 'WooCommerce', 'purosa' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $purosa_urls['woocommerce'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $purosa_urls['woocommerce'],
					'link_text'    => __( 'Learn More &#187;', 'purosa' ),
					'target_blank' => true
				),
			),
		),		
	);
	?>
		<div class="wrap deo-container">
			<h1 class="deo-title"><?php esc_html_e( 'Getting Started', 'purosa' ); ?></h1>
			<p class="deo-text">
				<?php					
					echo esc_html__( 'Purosa is now installed and ready to use! Get ready to build something beautiful. We hope you enjoy it! Before you get started, install all the required and recommended plugins, without them theme will lack some customizations.', 'purosa' );					
				?>
			</p>
			<h3><?php echo esc_html__( 'What is next?', 'purosa' ); ?></h3>
			<ul class="deo-list">
				<li>
					<?php
						/* translators: %1$s: Docs URL. */
						printf(
							esc_html__( 'Check the %1$s for installation and customization guides.', 'purosa' ),
							sprintf(
								'<a href="%s" target="_blank">%s</a>',
								esc_url( $purosa_urls['docs'] ),
								esc_html__( 'Documentation', 'purosa' )
							)
						);
					?>
				</li>
				<li>
					<?php
						/* translators: %1$s: Customizer URL. */
						printf(
							esc_html__( 'Go to %1$s to modify the look of your site. (requires active Kirki plugin)', 'purosa' ),
							sprintf(
								'<a href="%s" target="_blank">%s</a>',
								esc_url( admin_url( 'customize.php' ) ),
								esc_html__( 'Customizer', 'purosa' )
							)
						);
					?>
				</li>
				<li>
					<?php
						/* translators: %1$s: Contact URL. */
						printf(
							esc_html__( 'Need help? %1$s We\'re happy to help!', 'purosa' ),
							sprintf(
								'<a href="%s">%s</a>',
								esc_url( admin_url( 'themes.php?page=getting-started-contact' ) ),
								esc_html__( 'Get in touch with us.', 'purosa' )
							)
						);
					?>
				</li>
			</ul>

			<div class="postbox deo-postbox">
				<h2 class="deo-addon-title"><?php echo esc_html__( 'More features with Purosa Pro', 'purosa' ); ?></h2>
				<ul class="deo-addon-list">
					<?php
					foreach ( (array) $purosa_info as $addon => $info ) {
						$title_url     = ( isset( $info['title_url'] ) && ! empty( $info['title_url'] ) ) ? 'href="' . esc_url( $info['title_url'] ) . '"' : '';
						$anchor_target = ( isset( $info['title_url'] ) && ! empty( $info['title_url'] ) ) ? "target='_blank' rel='noopener'" : '';

						echo '<li class="' . esc_attr( $info['class'] ) . '"><a class="deo-addon-item-title"' . $title_url . $anchor_target . ' >' . esc_html( $info['title'] ) . '</a><div class="deo-addon-link-wrapper">';

							foreach ( $info['links'] as $key => $link ) {
								printf(
									'<a class="%1$s" %2$s %3$s> %4$s </a>',
									esc_attr( $link['link_class'] ),
									isset( $link['link_url'] ) ? 'href="' . esc_url( $link['link_url'] ) . '"' : '',
									( isset( $link['target_blank'] ) && $link['target_blank'] ) ? 'target="_blank" rel="noopener"' : '', // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
									esc_html( $link['link_text'] )
								);
							}

						echo '</div></li>';
					}
					?>
				</ul>
			</div>
		</div>
	<?php
}

/**
* Change theme icon
*
* @since 1.0.0
*/
function purosa_fs_custom_icon() {
  return PUROSA_THEME_DIR . '/assets/admin/img/theme-icon.jpg';
} 
purosa_fs()->add_filter( 'plugin_icon' , 'purosa_fs_custom_icon' );