<?php

/**
 * Theme setup.
 *
 * @package Purosa
 */
if ( !defined( 'ABSPATH' ) ) {
    exit( 'Direct script access denied.' );
}
if ( !function_exists( 'purosa_theme_setup' ) ) {
    // Sets up theme defaults and registers support for various WordPress features.
    function purosa_theme_setup()
    {
        // Enable theme support
        add_theme_support( 'post-thumbnails' );
        add_theme_support( 'title-tag' );
        add_theme_support( 'html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption'
        ) );
        add_theme_support( 'post-formats', array( 'video', 'audio' ) );
        add_theme_support( 'automatic-feed-links' );
        add_theme_support( 'custom-background', apply_filters( 'purosa_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        ) ) );
        // Gutenberg
        add_theme_support( 'align-wide' );
        add_theme_support( 'responsive-embeds' );
        add_editor_style();
        add_theme_support( 'editor-color-palette', array(
            array(
            'name'  => esc_html__( 'green', 'purosa' ),
            'slug'  => 'green',
            'color' => '#39B54A',
        ),
            array(
            'name'  => esc_html__( 'blue', 'purosa' ),
            'slug'  => 'blue',
            'color' => '#3d92ff',
        ),
            array(
            'name'  => esc_html__( 'pink', 'purosa' ),
            'slug'  => 'pink',
            'color' => '#f32855',
        ),
            array(
            'name'  => esc_html__( 'violet', 'purosa' ),
            'slug'  => 'violet',
            'color' => '#8c47e4',
        ),
            array(
            'name'  => esc_html__( 'light-grey', 'purosa' ),
            'slug'  => 'light-grey',
            'color' => '#f6f6f6',
        ),
            array(
            'name'  => esc_html__( 'dark-grey', 'purosa' ),
            'slug'  => 'dark-grey',
            'color' => '#1b1b1b',
        )
        ) );
        // Set size of thumbnails
        add_image_size(
            'purosa_thumbnail',
            100,
            75,
            true
        );
        add_image_size(
            'purosa_medium',
            370,
            259,
            true
        );
        add_image_size(
            'purosa_medium_large',
            570,
            399,
            true
        );
        add_image_size(
            'purosa_featured_large',
            770,
            482,
            true
        );
        add_image_size(
            'purosa_large',
            1170,
            480,
            true
        );
        // Nav menus
        register_nav_menus( array(
            'primary' => esc_html__( 'Primary Menu', 'purosa' ),
        ) );
    }

}
// theme_setup
add_action( 'after_setup_theme', 'purosa_theme_setup' );
// Update Elementor Defaults
if ( 1 != get_option( 'purosa_elementor_defaults', 0 ) ) {
    add_option( 'purosa_elementor_defaults', 0 );
}
function purosa_update_elementor_defaults()
{
    
    if ( 1 != get_option( 'purosa_elementor_defaults' ) ) {
        update_option( 'elementor_scheme_color', array(
            1 => '#777777',
            2 => '#242424',
            3 => '#969696',
            4 => '#39B54A',
        ) );
        update_option( 'elementor_scheme_color-picker', array(
            1 => '#39B54A',
            2 => '#969696',
            3 => '#908E99',
            4 => '#FF7070',
            5 => '#242424',
            6 => '#777777',
            7 => '#000000',
            8 => '#FFFFFF',
        ) );
        update_option( 'elementor_disable_color_schemes', 'yes' );
        update_option( 'elementor_disable_typography_schemes', 'yes' );
        update_option( 'purosa_elementor_defaults', 1 );
    }

}

add_action( 'init', 'purosa_update_elementor_defaults' );
// Register widget areas
function purosa_widgets_init()
{
    register_sidebar( array(
        'name'          => esc_html__( 'Sidebar', 'purosa' ),
        'id'            => 'purosa-sidebar',
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h4 class="widget-title">',
        'after_title'   => '</h4>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Newsletter Wide', 'purosa' ),
        'id'            => 'purosa-newsletter-wide',
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="widget-title newsletter-wide__title">',
        'after_title'   => '</h3>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Footer Instagram', 'purosa' ),
        'id'            => 'purosa-footer-instagram',
        'before_widget' => '<div id="%1$s" class="instagram-feed instagram-feed--wide text-center %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h5 class="instagram-feed__title">',
        'after_title'   => '</h5>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Footer Column 1', 'purosa' ),
        'id'            => 'purosa-footer-col-1',
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h5 class="widget-title">',
        'after_title'   => '</h5>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Footer Column 2', 'purosa' ),
        'id'            => 'purosa-footer-col-2',
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h5 class="widget-title">',
        'after_title'   => '</h5>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Footer Column 3', 'purosa' ),
        'id'            => 'purosa-footer-col-3',
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h5 class="widget-title">',
        'after_title'   => '</h5>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Footer Column 4', 'purosa' ),
        'id'            => 'purosa-footer-col-4',
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h5 class="widget-title">',
        'after_title'   => '</h5>',
    ) );
}

add_action( 'widgets_init', 'purosa_widgets_init' );
// TGMPA plugins activation

if ( is_admin() ) {
    require_once PUROSA_THEME_DIR . '/includes/class-tgm-plugin-activation.php';
    add_action( 'tgmpa_register', 'purosa_tgmpa_register_required_plugins' );
}

function purosa_tgmpa_register_required_plugins()
{
    $plugins = array(
        array(
        'name'     => 'Kirki',
        'slug'     => 'kirki',
        'required' => false,
    ),
        array(
        'name'     => 'Smash Balloon Social Photo Feed',
        'slug'     => 'instagram-feed',
        'required' => false,
    ),
        array(
        'name'     => 'Contact Form 7',
        'slug'     => 'contact-form-7',
        'required' => false,
    ),
        array(
        'name'     => 'MailChimp for WordPress',
        'slug'     => 'mailchimp-for-wp',
        'required' => false,
    )
    );
    $config = array(
        'id'           => 'tgmpa',
        'default_path' => '',
        'menu'         => 'tgmpa-install-plugins',
        'capability'   => 'edit_theme_options',
        'has_notices'  => true,
        'dismissable'  => true,
        'dismiss_msg'  => '',
        'is_automatic' => true,
        'message'      => '',
        'strings'      => array(
        'page_title'                     => esc_html__( 'Install Required Plugins', 'purosa' ),
        'menu_title'                     => esc_html__( 'Install Plugins', 'purosa' ),
        'installing'                     => esc_html__( 'Installing Plugin: %s', 'purosa' ),
        'updating'                       => esc_html__( 'Updating Plugin: %s', 'purosa' ),
        'oops'                           => esc_html__( 'Something went wrong with the plugin API.', 'purosa' ),
        'return'                         => esc_html__( 'Return to Required Plugins Installer', 'purosa' ),
        'plugin_activated'               => esc_html__( 'Plugin activated successfully.', 'purosa' ),
        'activated_successfully'         => esc_html__( 'The following plugin was activated successfully:', 'purosa' ),
        'plugin_already_active'          => esc_html__( 'No action taken. Plugin %1$s was already active.', 'purosa' ),
        'plugin_needs_higher_version'    => esc_html__( 'Plugin not activated. A higher version of %s is needed for this theme. Please update the plugin.', 'purosa' ),
        'complete'                       => esc_html__( 'All plugins installed and activated successfully. %1$s', 'purosa' ),
        'dismiss'                        => esc_html__( 'Dismiss this notice', 'purosa' ),
        'notice_cannot_install_activate' => esc_html__( 'There are one or more required or recommended plugins to install, update or activate.', 'purosa' ),
        'contact_admin'                  => esc_html__( 'Please contact the administrator of this site for help.', 'purosa' ),
        'nag_type'                       => 'updated',
    ),
    );
    tgmpa( $plugins, $config );
}

/*
 * Disable Kirki telemetry
 */
add_filter( 'kirki_telemetry', '__return_false' );
/**
 * Remove admin notices for Instagram Feed
 */
add_action( 'admin_init', 'remove_insta_alerts' );
function remove_insta_alerts()
{
    remove_action( 'admin_notices', 'sbi_notices_html', 8 );
    remove_action( 'admin_notices', 'sbi_usage_opt_in' );
}

/**
 * Add extra permissions to Freemius
 */
function purosa_freemius_extra_permissions( $permissions )
{
    $permissions['newsletter'] = array(
        'icon-class' => 'dashicons dashicons-email-alt',
        'label'      => purosa_fs()->get_text_inline( 'Newsletter', 'purosa' ),
        'desc'       => purosa_fs()->get_text_inline( 'Your email is added to our newsletter. Updates, announcements, marketing, no spam. Unsubscribe anytime.', 'purosa' ),
        'priority'   => 15,
    );
    return $permissions;
}

purosa_fs()->add_filter( 'permission_list', 'purosa_freemius_extra_permissions' );